@@ -61,7 +61,7 @@ public: // method
                             ControlAction action,
                             ControlIdentifiers identifiers) override;
 
-    MoveIterator move(const FDBToolRequest& request, const eckit::URI& dest, bool removeSrc, int removeDelay, bool mpi, int threads) override;
+    MoveIterator move(const FDBToolRequest& request, const eckit::URI& dest) override;
 
     void flush() override;
 
