@@ -21,10 +21,11 @@
 
 #include <memory>
 
+#include "eckit/distributed/Transport.h"
 #include "eckit/utils/Regex.h"
 #include "eckit/memory/NonCopyable.h"
 
-#include "fdb5/database/DB.h"
+#include "fdb5/database/Catalogue.h"
 #include "fdb5/config/Config.h"
 #include "fdb5/api/FDBStats.h"
 #include "fdb5/api/helpers/ListIterator.h"
@@ -37,13 +38,17 @@
 #include "fdb5/api/helpers/StatsIterator.h"
 #include "fdb5/api/helpers/StatusIterator.h"
 
-namespace eckit {
-namespace message {
-class Message;
-}
-}  // namespace eckit
+namespace eckit::message {
 
-namespace metkit { class MarsRequest; }
+class Message;
+
+}  // namespace eckit::message
+
+namespace metkit {
+
+class MarsRequest;
+
+} // namespace metkit
 
 namespace fdb5 {
 
@@ -85,7 +90,7 @@ public: // methods
                                     ControlAction action,
                                     ControlIdentifiers identifier) = 0;
 
-    virtual MoveIterator move(const FDBToolRequest& request, const eckit::URI& dest, bool removeSrc, int removeDelay, bool mpi, int threads) = 0;
+    virtual MoveIterator move(const FDBToolRequest& request, const eckit::URI& dest) = 0;
 
     // -------------- API management ----------------------------
 
