@@ -21,7 +21,7 @@
 #include "fdb5/api/helpers/FDBToolRequest.h"
 #include "fdb5/api/LocalFDB.h"
 #include "fdb5/database/Archiver.h"
-#include "fdb5/database/DB.h"
+#include "fdb5/database/Catalogue.h"
 #include "fdb5/database/EntryVisitMechanism.h"
 #include "fdb5/database/Index.h"
 #include "fdb5/database/Inspector.h"
@@ -101,9 +101,9 @@ WipeIterator LocalFDB::wipe(const FDBToolRequest &request, bool doit, bool porce
     return queryInternal<fdb5::api::local::WipeVisitor>(request, doit, porcelain, unsafeWipeAll);
 }
 
-MoveIterator LocalFDB::move(const FDBToolRequest& request, const eckit::URI& dest, bool removeSrc, int removeDelay, bool mpi, int threads) {
+MoveIterator LocalFDB::move(const FDBToolRequest& request, const eckit::URI& dest) {
     Log::debug<LibFdb5>() << "LocalFDB::move() : " << request << std::endl;
-    return queryInternal<fdb5::api::local::MoveVisitor>(request, dest, removeSrc, removeDelay, mpi, threads);
+    return queryInternal<fdb5::api::local::MoveVisitor>(request, dest);
 }
 
 PurgeIterator LocalFDB::purge(const FDBToolRequest& request, bool doit, bool porcelain) {
@@ -136,7 +136,7 @@ void LocalFDB::print(std::ostream &s) const {
 
 
 static FDBBuilder<LocalFDB> localFdbBuilder("local");
-
+static FDBBuilder<LocalFDB> builder("catalogue"); // Enable type=catalogue to build localFDB (serverside).
 //----------------------------------------------------------------------------------------------------------------------
 
 } // namespace fdb5
