@@ -57,18 +57,20 @@ public: // methods
                             ControlAction action,
                             ControlIdentifiers identifiers) override;
 
-    MoveIterator move(const FDBToolRequest& request, const eckit::URI& dest, bool removeSrc, int removeDelay, bool mpi, int threads) override;
+    MoveIterator move(const FDBToolRequest& request, const eckit::URI& dest) override;
 
     void flush() override;
 
+protected: // methods
+
+    template <typename VisitorType, typename ... Ts>
+    APIIterator<typename VisitorType::ValueType> queryInternal(const FDBToolRequest& request, Ts ... args);
+
 private: // methods
 
     void print(std::ostream& s) const override;
 
-    template <typename VisitorType, typename ... Ts>
-    APIIterator<typename VisitorType::ValueType> queryInternal(const FDBToolRequest& request, Ts ... args);
-
-private: // members
+protected: // members
 
     std::string home_;
 
