@@ -21,8 +21,6 @@
 
 #include "fdb5/api/helpers/APIIterator.h"
 
-#include "eckit/filesystem/PathName.h"
-
 #include <string>
 
 /*
@@ -32,8 +30,6 @@
 
 namespace fdb5 {
 
-class IndexLocation;
-
 //----------------------------------------------------------------------------------------------------------------------
 
 using WipeElement = std::string;
