@@ -19,8 +19,9 @@
 #ifndef fdb5_api_local_ListVisitor_H
 #define fdb5_api_local_ListVisitor_H
 
-#include "fdb5/database/DB.h"
+#include "fdb5/database/Catalogue.h"
 #include "fdb5/database/Index.h"
+#include "fdb5/database/InspectionKey.h"
 #include "fdb5/api/local/QueryVisitor.h"
 #include "fdb5/api/helpers/ListIterator.h"
 
@@ -39,14 +40,16 @@ public:
 
     /// Make a note of the current database. Subtract its key from the current
     /// request so we can test request is used in its entirety
-    bool visitDatabase(const Catalogue& catalogue, const Store& store) override {
+//    bool visitDatabase(const Catalogue& catalogue, const Store& store) override {
+    bool visitDatabase(const Catalogue& catalogue) override {
 
         // If the DB is locked for listing, then it "doesn't exist"
         if (!catalogue.enabled(ControlIdentifier::List)) {
             return false;
         }
 
-        bool ret = QueryVisitor::visitDatabase(catalogue, store);
+//        bool ret = QueryVisitor::visitDatabase(catalogue, store);
+        bool ret = QueryVisitor::visitDatabase(catalogue);
         ASSERT(catalogue.key().partialMatch(request_));
 
         // Subselect the parts of the request
@@ -72,19 +75,19 @@ public:
             datumRequest_.unsetValues(kv.first);
         }
 
-        if (index.key().partialMatch(request_)) {
+        if (index.partialMatch(request_)) {
             return true; // Explore contained entries
         }
         return false; // Skip contained entries
     }
 
     /// Test if entry matches the current request. If so, add to the output queue.
-    void visitDatum(const Field& field, const Key& key) override {
+    void visitDatum(const Field& field, const InspectionKey& datumKey) override {
         ASSERT(currentCatalogue_);
         ASSERT(currentIndex_);
 
-        if (key.match(datumRequest_)) {
-            queue_.emplace(ListElement({currentCatalogue_->key(), currentIndex_->key(), key}, field.stableLocation(), field.timestamp()));
+        if (datumKey.match(datumRequest_)) {
+            queue_.emplace(ListElement({currentCatalogue_->key(), currentIndex_->key(), datumKey.canonical()}, field.stableLocation(), field.timestamp()));
         }
     }
 
