@@ -37,6 +37,12 @@ public:
         return me;
     }
 
+    const Schema& add(const PathName& path, Schema* schema) {
+        ASSERT(schema);
+        schemas_[path] = std::unique_ptr<Schema>(schema);
+        return *schemas_[path];
+    }
+
     const Schema& get(const PathName& path) {
         std::lock_guard<std::mutex> lock(m_);
         auto it = schemas_.find(path);
@@ -57,7 +63,7 @@ private:
 
 //----------------------------------------------------------------------------------------------------------------------
 
-Config::Config() : schemaPath_("") {
+Config::Config() : schemaPath_(""), schemaPathInitialised_(false) {
     userConfig_ = std::make_shared<eckit::LocalConfiguration>(eckit::LocalConfiguration());
 }
 
@@ -71,8 +77,8 @@ Config Config::make(const eckit::PathName& path, const eckit::Configuration& use
 }
 
 Config::Config(const Configuration& config, const eckit::Configuration& userConfig) :
-    LocalConfiguration(config) {
-    initializeSchemaPath();
+    LocalConfiguration(config), schemaPathInitialised_(false) {
+    // initializeSchemaPath();
     userConfig_ = std::make_shared<eckit::LocalConfiguration>(userConfig);
 }
 
@@ -170,14 +176,27 @@ PathName Config::expandPath(const std::string& path) const {
 }
 
 const PathName& Config::schemaPath() const {
-    if (schemaPath_.path().empty()) {
+    if (schemaPath_.path().empty() || !schemaPathInitialised_) {
         initializeSchemaPath();
     }
     return schemaPath_;
 }
 
+void Config::overrideSchema(const eckit::PathName& schemaPath, Schema* schema) {
+    ASSERT(schema);
+
+    schema->path_ = schemaPath;
+    SchemaRegistry::instance().add(schemaPath, schema);
+
+    schemaPath_=schemaPath;
+    schemaPathInitialised_ = true;
+}
+
 void Config::initializeSchemaPath() const {
 
+    if (schemaPathInitialised_) {
+        return;
+    }
     // If the user has specified the schema location in the FDB config, use that,
     // otherwise use the library-wide schema path.
 
@@ -193,6 +212,7 @@ void Config::initializeSchemaPath() const {
         schemaPath_ = expandPath(fdbSchemaFile);
     }
 
+    schemaPathInitialised_ = true;
     eckit::Log::debug<LibFdb5>() << "Using FDB schema: " << schemaPath_ << std::endl;
 }
 
@@ -201,6 +221,7 @@ PathName Config::configPath() const {
 }
 
 const Schema& Config::schema() const {
+    initializeSchemaPath();
     return SchemaRegistry::instance().get(schemaPath());
 }
 
