@@ -18,22 +18,27 @@
 #include "fdb5/database/BaseArchiveVisitor.h"
 #include "fdb5/rules/Schema.h"
 #include "fdb5/rules/Rule.h"
+#include "fdb5/database/Store.h"
 
 namespace fdb5 {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-
 Archiver::Archiver(const Config& dbConfig) :
     dbConfig_(dbConfig),
-    current_(nullptr) {
-}
+    catalogue_(nullptr),
+    store_(nullptr) {}
 
 Archiver::~Archiver() {
-
     flush(); // certify that all sessions are flushed before closing them
 
-    databases_.clear(); //< explicitly delete the DBs before schemas are destroyed
+    // for (auto it = databases_.begin(); it != databases_.end(); it++) {
+    //     databases_.erase(it);
+    // }
+
+//    std::cout << databases_.size();
+
+    // databases_.clear(); //< explicitly delete the DBs before schemas are destroyed
 }
 
 void Archiver::archive(const Key &key, const void* data, size_t len) {
@@ -44,31 +49,35 @@ void Archiver::archive(const Key &key, const void* data, size_t len) {
 void Archiver::archive(const Key &key, BaseArchiveVisitor& visitor) {
 
     visitor.rule(nullptr);
-
+    
     dbConfig_.schema().expand(key, visitor);
 
-    if (visitor.rule() == nullptr) { // Make sure we did find a rule that matched
+    const Rule* rule = visitor.rule();
+    if (rule == nullptr) { // Make sure we did find a rule that matched
         std::ostringstream oss;
         oss << "FDB: Could not find a rule to archive " << key;
         throw eckit::SeriousBug(oss.str());
     }
+    // validate metadata
+    rule->check(key);
 }
 
 void Archiver::flush() {
-    for (store_t::iterator i = databases_.begin(); i != databases_.end(); ++i) {
-        i->second.second->flush();
+    for (auto i = databases_.begin(); i != databases_.end(); ++i) {
+        i->second.store_->flush();      // flush the store
+        i->second.catalogue_->flush();  // flush the catalogue
     }
 }
 
+void Archiver::selectDatabase(const Key &dbKey) {
 
-DB& Archiver::database(const Key &key) {
-
-    store_t::iterator i = databases_.find(key);
+    auto i = databases_.find(dbKey);
 
     if (i != databases_.end() ) {
-        DB& db = *(i->second.second);
-        i->second.first = ::time(0);
-        return db;
+        catalogue_ = i->second.catalogue_.get();
+        store_ = i->second.store_.get();
+        i->second.time_ = ::time(0);
+        return;
     }
 
     static size_t fdbMaxNbDBsOpen = eckit::Resource<size_t>("fdbMaxNbDBsOpen", 64);
@@ -77,33 +86,37 @@ DB& Archiver::database(const Key &key) {
         bool found = false;
         time_t oldest = ::time(0) + 24 * 60 * 60;
         Key oldK;
-        for (store_t::iterator i = databases_.begin(); i != databases_.end(); ++i) {
-            if (i->second.first <= oldest) {
+        for (auto i = databases_.begin(); i != databases_.end(); ++i) {
+            if (i->second.time_ <= oldest) {
                 found = true;
                 oldK = i->first;
-                oldest = i->second.first;
+                oldest = i->second.time_;
             }
         }
         if (found) {
-            eckit::Log::info() << "Closing database " << *databases_[oldK].second << std::endl;
+            databases_[oldK].store_->flush();
+            databases_[oldK].catalogue_->flush();
+            
+            eckit::Log::info() << "Closing database " << *databases_[oldK].catalogue_ << std::endl;
             databases_.erase(oldK);
         }
     }
 
-    std::unique_ptr<DB> db = DB::buildWriter(key, dbConfig_);
-
-    ASSERT(db);
+    std::unique_ptr<CatalogueWriter> cat = CatalogueWriterFactory::instance().build(dbKey, dbConfig_);
+    ASSERT(cat);
 
     // If this database is locked for writing then this is an error
-    if (!db->enabled(ControlIdentifier::Archive)) {
+    if (!cat->enabled(ControlIdentifier::Archive)) {
         std::ostringstream ss;
-        ss << "Database " << *db << " matched for archived is LOCKED against archiving";
+        ss << "Database " << *cat << " matched for archived is LOCKED against archiving";
         throw eckit::UserError(ss.str(), Here());
     }
 
-    DB& out = *db;
-    databases_[key] = std::make_pair(::time(0), std::move(db));
-    return out;
+    std::unique_ptr<Store> str = cat->buildStore();
+    catalogue_ = cat.get();
+    store_ = str.get();
+
+    databases_[dbKey] = Database{::time(0), std::move(cat), std::move(str)};
 }
 
 void Archiver::print(std::ostream &out) const {
