@@ -12,9 +12,11 @@
 #include "eckit/log/Log.h"
 #include "eckit/exception/Exceptions.h"
 
+#include "metkit/mars/MarsRequest.h"
+
 #include "fdb5/database/AxisRegistry.h"
 #include "fdb5/database/IndexAxis.h"
-#include "fdb5/database/Key.h"
+#include "fdb5/database/InspectionKey.h"
 #include "fdb5/types/TypesRegistry.h"
 #include "fdb5/types/Type.h"
 
@@ -128,7 +130,7 @@ void IndexAxis::decodeCurrent(eckit::Stream &s, const int version) {
                 ASSERT(n);
                 for (size_t i = 0; i < n; i++) {
                     s >> k;
-                    std::shared_ptr<eckit::DenseSet<std::string> >& values = axis_[k];
+                    std::shared_ptr<eckit::DenseSet<std::string>>& values = axis_[k];
                     values.reset(new eckit::DenseSet<std::string>);
                     size_t m;
                     s >> m;
@@ -148,6 +150,7 @@ void IndexAxis::decodeCurrent(eckit::Stream &s, const int version) {
 }
 
 void IndexAxis::decodeLegacy(eckit::Stream& s, const int version) {
+
     ASSERT(version <= 2);
 
     size_t n;
@@ -158,7 +161,7 @@ void IndexAxis::decodeLegacy(eckit::Stream& s, const int version) {
 
     for (size_t i = 0; i < n; i++) {
         s >> k;
-        std::shared_ptr<eckit::DenseSet<std::string> >& values = axis_[k];
+        std::shared_ptr<eckit::DenseSet<std::string>>& values = axis_[k];
         values.reset(new eckit::DenseSet<std::string>);
         size_t m;
         s >> m;
@@ -190,7 +193,35 @@ void IndexAxis::dump(std::ostream &out, const char* indent) const {
    // out << std::endl;
 }
 
-bool IndexAxis::contains(const Key &key) const {
+bool IndexAxis::partialMatch(const metkit::mars::MarsRequest& request) const {
+
+    // We partially match on a request
+    //
+    // --> keys that are in the request, but not the axis are OK (other parts of the request)
+    // --> keys that are in the axis, but not the request are OK (list doesn't need to specify everything)
+    //
+    // BUT keys tha correspond to the axis object, but do not match it, should result
+    // in the match failing (this will be the common outcome during the model run, when many
+    // indexes exist)
+
+    for (const auto& kv : axis_) {
+        if (request.has(kv.first)) {
+            bool found = false;
+            for (const auto& rqval : request.values(kv.first)) {
+                if (kv.second->contains(rqval)) {
+                    found = true;
+                    break;;
+                }
+            }
+
+            if (!found) return false;
+        }
+    }
+
+    return true;
+}
+
+bool IndexAxis::contains(const InspectionKey &key) const {
 
     for (AxisMap::const_iterator i = axis_.begin(); i != axis_.end(); ++i) {
         if (!key.match(i->first, *(i->second))) {
@@ -200,13 +231,13 @@ bool IndexAxis::contains(const Key &key) const {
     return true;
 }
 
-void IndexAxis::insert(const Key &key) {
+void IndexAxis::insert(const InspectionKey &key) {
     ASSERT(!readOnly_);
 
     for (Key::const_iterator i = key.begin(); i  != key.end(); ++i) {
         const std::string &keyword = i->first;
 
-        std::shared_ptr<eckit::DenseSet<std::string> >& axis_set = axis_[keyword];
+        std::shared_ptr<eckit::DenseSet<std::string>>& axis_set = axis_[keyword];
         if (!axis_set)
             axis_set.reset(new eckit::DenseSet<std::string>);
 
@@ -239,6 +270,10 @@ void IndexAxis::wipe() {
     clean();
 }
 
+bool IndexAxis::has(const std::string &keyword) const {
+    AxisMap::const_iterator i = axis_.find(keyword);
+    return (i != axis_.end());
+}
 
 const eckit::DenseSet<std::string> &IndexAxis::values(const std::string &keyword) const {
 
