@@ -29,9 +29,13 @@ namespace eckit {
 class Stream;
 }
 
+namespace metkit::mars {
+class MarsRequest;
+}
+
 namespace fdb5 {
 
-class Key;
+class InspectionKey;
 
 //----------------------------------------------------------------------------------------------------------------------
 
@@ -44,17 +48,19 @@ public: // methods
 
     ~IndexAxis();
 
-    void insert(const Key &key);
+    void insert(const InspectionKey &key);
     void encode(eckit::Stream &s, const int version) const;
 
     // Decode can be used for two-stage initialisation (IndexAxis a; a.decode(s);)
     void decode(eckit::Stream& s, const int version);
 
+    bool has(const std::string &keyword) const;
     const eckit::DenseSet<std::string> &values(const std::string &keyword) const;
 
     void dump(std::ostream &out, const char* indent) const;
 
-    bool contains(const Key& key) const;
+    bool partialMatch(const metkit::mars::MarsRequest& request) const;
+    bool contains(const InspectionKey& key) const;
 
     /// Provide a means to test if the index has changed since it was last written out, and to
     /// mark that it has been written out.
@@ -85,7 +91,7 @@ private: // methods
 
 private: // members
 
-    typedef std::map<std::string, std::shared_ptr<eckit::DenseSet<std::string> > > AxisMap;
+    typedef std::map<std::string, std::shared_ptr<eckit::DenseSet<std::string>>> AxisMap;
     AxisMap axis_;
 
     bool readOnly_;
