@@ -10,8 +10,10 @@
 
 #include <algorithm>
 
+#include "eckit/config/Resource.h"
 #include "eckit/container/DenseSet.h"
 #include "eckit/utils/Tokenizer.h"
+#include "eckit/utils/StringTools.h"
 
 #include "metkit/mars/MarsRequest.h"
 
@@ -27,25 +29,10 @@ namespace fdb5 {
 //----------------------------------------------------------------------------------------------------------------------
 
 Key::Key() :
-    keys_(),
-    rule_(0) {}
-
-Key::Key(const std::string &s, const Rule *rule) :
-    keys_(),
-    rule_(0) {
-    eckit::Tokenizer parse(":", true);
-    eckit::StringList values;
-    parse(s, values);
-
-    ASSERT(rule);
-    rule->fill(*this, values);
-}
+    keys_(), names_() {}
 
 Key::Key(const std::string &s) :
-    keys_(),
-    rule_(0) {
-
-    const TypesRegistry &registry = this->registry();
+    keys_(), names_() {
 
     eckit::Tokenizer parse1(",");
     eckit::StringList v;
@@ -58,22 +45,17 @@ Key::Key(const std::string &s) :
         parse2(*i, kv);
         ASSERT(kv.size() == 2);
 
-        const Type &t = registry.lookupType(kv[0]);
-
-        std::string v = t.tidy(kv[0], kv[1]);
-
         if (find(kv[0]) == end()) {
-            push(kv[0], v);
+            push(kv[0], kv[1]);
         } else {
-            set(kv[0], v);
+            set(kv[0], kv[1]);
         }
     }
 
 }
 
 Key::Key(const eckit::StringDict &keys) :
-    keys_(keys),
-    rule_(0) {
+    keys_(keys) {
 
     eckit::StringDict::const_iterator it = keys.begin();
     eckit::StringDict::const_iterator end = keys.end();
@@ -82,19 +64,15 @@ Key::Key(const eckit::StringDict &keys) :
     }
 }
 
-Key::Key(eckit::Stream& s) :
-    rule_(nullptr) {
+Key::Key(eckit::Stream& s) {
     decode(s);
 }
 
 void Key::decode(eckit::Stream& s) {
 
-    ASSERT(rule_ == nullptr);
-
     keys_.clear();
     names_.clear();
 
-
     size_t n;
 
     s >> n;
@@ -103,7 +81,7 @@ void Key::decode(eckit::Stream& s) {
     for (size_t i = 0; i < n; ++i) {
         s >> k;
         s >> v;
-        keys_[k] = v;
+        keys_[k] = eckit::StringTools::lower(v);
     }
 
     s >> n;
@@ -115,20 +93,17 @@ void Key::decode(eckit::Stream& s) {
 }
 
 void Key::encode(eckit::Stream& s) const {
-    const TypesRegistry& registry = this->registry();
 
     s << keys_.size();
     for (eckit::StringDict::const_iterator i = keys_.begin(); i != keys_.end(); ++i) {
-        const Type &t = registry.lookupType(i->first);
-        s << i->first << canonicalise(i->first, i->second);
-
+        s << i->first;
+        s << i->second;
     }
 
     s << names_.size();
-    for (eckit::StringList::const_iterator i = names_.begin(); i != names_.end(); ++i) {
-        const Type &t = registry.lookupType(*i);
-        s << (*i);
-        s << t.type();
+    for (const auto& name : names_) {
+        s << name;
+        s << "";
     }
 }
 
@@ -143,15 +118,6 @@ std::set<std::string> Key::keys() const {
     return k;
 }
 
-
-void Key::rule(const Rule *rule) {
-    rule_ = rule;
-}
-
-const Rule *Key::rule() const {
-    return rule_;
-}
-
 void Key::clear() {
     keys_.clear();
     names_.clear();
@@ -162,9 +128,9 @@ void Key::set(const std::string &k, const std::string &v) {
     eckit::StringDict::iterator it = keys_.find(k);
     if (it == keys_.end()) {
         names_.push_back(k);
-        keys_[k] = v;
+        keys_[k] = eckit::StringTools::lower(v);
     } else {
-        it->second = v;
+        it->second = eckit::StringTools::lower(v);
     }
 
 }
@@ -174,7 +140,7 @@ void Key::unset(const std::string &k) {
 }
 
 void Key::push(const std::string &k, const std::string &v) {
-    keys_[k] = v;
+    keys_[k] = eckit::StringTools::lower(v);
     names_.push_back(k);
 }
 
@@ -291,28 +257,10 @@ bool Key::partialMatch(const metkit::mars::MarsRequest& request) const {
 }
 
 
-const TypesRegistry& Key::registry() const {
-    if(rule_) {
-        return rule_->registry();
-    }
-    else {
-        return LibFdb5::instance().defaultConfig().schema().registry();
-    }
-}
-
-std::string Key::canonicalise(const std::string& keyword, const std::string& value) const {
-    if (value.empty()) {
-        return value;
-    } else {
-        return this->registry().lookupType(keyword).toKey(keyword, value);
-    }
-}
-
 std::string Key::canonicalValue(const std::string& keyword) const {
 
     eckit::StringDict::const_iterator it = keys_.find(keyword);
     ASSERT(it != keys_.end());
-
     return canonicalise(keyword, it->second);
 }
 
@@ -329,14 +277,38 @@ std::string Key::valuesToString() const {
 
         oss << sep;
         oss << canonicalise(*j, i->second);
-
+        
         sep = ":";
     }
-
     return oss.str();
 }
 
 
+void Key::validateKeysOf(const Key& other) const
+{
+    eckit::StringSet missing;
+
+    for (Key::const_iterator j = begin(); j != end(); ++j) {
+        const std::string& keyword = (*j).first;
+        Key::const_iterator k = other.find(keyword);
+        if (k == other.end()) {
+            missing.insert(keyword);
+        }
+    }
+
+    if (missing.size()) {
+        std::ostringstream oss;
+
+        if(missing.size()) {
+            oss << "Keywords not used: " << missing << " ";
+        }
+        oss << "for key " << *this << " validating " << other;
+
+        throw eckit::SeriousBug(oss.str());
+    }
+}
+
+
 const eckit::StringList& Key::names() const {
     return names_;
 }
@@ -348,47 +320,6 @@ std::string Key::value(const std::string& key) const {
     return it->second;
 }
 
-void Key::validateKeysOf(const Key& other, bool checkAlsoValues) const
-{
-    eckit::StringSet missing;
-    eckit::StringSet mismatch;
-
-    const TypesRegistry& registry = this->registry();
-
-    for (Key::const_iterator j = begin(); j != end(); ++j) {
-        const std::string& keyword = (*j).first;
-        Key::const_iterator k = other.find(keyword);
-        if (k == other.end()) {
-            missing.insert(keyword);
-        }
-        else {
-            if(checkAlsoValues && !registry.lookupType(keyword).match(keyword, k->second, j->second) ) {
-                mismatch.insert((*j).first + "=" + j->second + " and " + k->second);
-            }
-        }
-    }
-
-    if (missing.size() || mismatch.size()) {
-        std::ostringstream oss;
-
-        if(missing.size()) {
-            oss << "Keywords not used: " << missing << " ";
-        }
-
-        if(mismatch.size()) {
-            oss << "Values mismatch: " << mismatch << " ";
-        }
-
-        oss << "for key " << *this << " validating " << other;
-
-        if (rule()) {
-            oss << " " << *rule();
-        }
-
-        throw eckit::SeriousBug(oss.str());
-    }
-}
-
 const eckit::StringDict &Key::keyDict() const {
     return keys_;
 }
@@ -409,14 +340,17 @@ fdb5::Key::operator std::string() const {
     return toString();
 }
 
+std::string Key::canonicalise(const std::string&, const std::string& value) const {
+
+    return value;
+}
+
 fdb5::Key::operator eckit::StringDict() const
 {
     eckit::StringDict res;
 
     ASSERT(names_.size() == keys_.size());
 
-    const TypesRegistry &registry = this->registry();
-
     for (eckit::StringList::const_iterator j = names_.begin(); j != names_.end(); ++j) {
 
         eckit::StringDict::const_iterator i = keys_.find(*j);
@@ -424,7 +358,7 @@ fdb5::Key::operator eckit::StringDict() const
         ASSERT(i != keys_.end());
         ASSERT(!(*i).second.empty());
 
-        res[*j] = registry.lookupType(*j).tidy(*j, (*i).second);
+        res[*j] = (*i).second;
     }
 
     return res;
@@ -433,14 +367,8 @@ fdb5::Key::operator eckit::StringDict() const
 void Key::print(std::ostream &out) const {
     if (names_.size() == keys_.size()) {
         out << "{" << toString() << "}";
-        if (rule_) {
-            out << " (" << *rule_ << ")";
-        }
     } else {
         out << keys_;
-        if (rule_) {
-            out << " (" << *rule_ << ")";
-        }
     }
 }
 
