@@ -15,18 +15,10 @@ namespace fdb5 {
 //----------------------------------------------------------------------------------------------------------------------
 
 MoveVisitor::MoveVisitor(const metkit::mars::MarsRequest& request,
-                         const eckit::URI& dest,
-                         bool removeSrc,
-                         int removeDelay,
-                         bool mpi,
-                         int threads) :
+                         const eckit::URI& dest) :
     EntryVisitor(),
     request_(request),
-    dest_(dest),
-    removeSrc_(removeSrc),
-    removeDelay_(removeDelay),
-    mpi_(mpi),
-    threads_(threads) {}
+    dest_(dest) {}
 
 MoveVisitor::~MoveVisitor() {}
 
