@@ -581,7 +581,7 @@ std::string RootManager::dbPathName(const Key& key)
     return dbpath;
 }
 
-std::vector<std::string> RootManager::possibleDbPathNames(const Key& key, const char* missing)
+std::vector<std::string> RootManager::possibleDbPathNames(const InspectionKey& key, const char* missing)
 {
     std::vector<std::string> result;
     for (DbPathNamerTable::const_iterator i = dbPathNamers_.begin(); i != dbPathNamers_.end() ; ++i) {
@@ -631,9 +631,9 @@ TocPath RootManager::directory(const Key& key) {
 
     for (FileSpaceTable::const_iterator i = spacesTable_.begin(); i != spacesTable_.end() ; ++i) {
         if(i->match(keystr)) {
-            TocPath root = i->filesystem(key, dbpath);
-            eckit::Log::debug<LibFdb5>() << "Directory root " << root.directory_ << " dbpath " << dbpath <<  std::endl;
-            return TocPath{root.directory_ / dbpath, root.controlIdentifiers_};
+            TocPath db = i->filesystem(key, dbpath);
+            eckit::Log::debug<LibFdb5>() << "Database directory " << db.directory_ << std::endl;
+            return db;
         }
     }
 
@@ -657,7 +657,7 @@ std::vector<PathName> RootManager::allRoots(const Key& key)
     return std::vector<eckit::PathName>(roots.begin(), roots.end());
 }
 
-std::vector<PathName> RootManager::visitableRoots(const std::set<Key>& keys) {
+std::vector<PathName> RootManager::visitableRoots(const std::set<InspectionKey>& keys) {
 
     eckit::StringSet roots;
 
@@ -688,15 +688,15 @@ std::vector<PathName> RootManager::visitableRoots(const std::set<Key>& keys) {
 }
 
 
-std::vector<eckit::PathName> RootManager::visitableRoots(const Key& key) {
-    return visitableRoots(std::set<Key>{ key });
+std::vector<eckit::PathName> RootManager::visitableRoots(const InspectionKey& key) {
+    return visitableRoots(std::set<InspectionKey>{ key });
 }
 
 std::vector<eckit::PathName> RootManager::visitableRoots(const metkit::mars::MarsRequest& request) {
 
 //    Key key;
 //    config_.schema().expandFirstLevel(request, key);
-    std::set<Key> keys;
+    std::set<InspectionKey> keys;
     config_.schema().matchFirstLevel(request, keys, "");
     return visitableRoots(keys);
 }
