@@ -21,6 +21,7 @@
 #include "fdb5/toc/TocCatalogueWriter.h"
 #include "fdb5/toc/TocFieldLocation.h"
 #include "fdb5/toc/TocIndex.h"
+#include "fdb5/toc/RootManager.h"
 #include "fdb5/io/LustreSettings.h"
 
 using namespace eckit;
@@ -30,10 +31,10 @@ namespace fdb5 {
 //----------------------------------------------------------------------------------------------------------------------
 
 
-TocCatalogueWriter::TocCatalogueWriter(const Key &key, const fdb5::Config& config) :
-    TocCatalogue(key, config),
+TocCatalogueWriter::TocCatalogueWriter(const Key &dbKey, const fdb5::Config& config) :
+    TocCatalogue(dbKey, config),
     umask_(config.umask()) {
-    writeInitRecord(key);
+    writeInitRecord(dbKey);
     TocCatalogue::loadSchema();
     TocCatalogue::checkUID();
 }
@@ -51,21 +52,21 @@ TocCatalogueWriter::~TocCatalogueWriter() {
     close();
 }
 
-bool TocCatalogueWriter::selectIndex(const Key& key) {
-    currentIndexKey_ = key;
+bool TocCatalogueWriter::selectIndex(const Key& idxKey) {
+    currentIndexKey_ = idxKey;
 
-    if (indexes_.find(key) == indexes_.end()) {
-        PathName indexPath(generateIndexPath(key));
+    if (indexes_.find(idxKey) == indexes_.end()) {
+        PathName indexPath(generateIndexPath(idxKey));
 
         // Enforce lustre striping if requested
         if (stripeLustre()) {
             fdb5LustreapiFileCreate(indexPath.localPath(), stripeIndexLustreSettings());
         }
 
-        indexes_[key] = Index(new TocIndex(key, indexPath, 0, TocIndex::WRITE));
+        indexes_[idxKey] = Index(new TocIndex(idxKey, indexPath, 0, TocIndex::WRITE));
     }
 
-    current_ = indexes_[key];
+    current_ = indexes_[idxKey];
     current_.open();
     current_.flock();
 
@@ -74,20 +75,20 @@ bool TocCatalogueWriter::selectIndex(const Key& key) {
 
     if (useSubToc()) {
 
-        if (fullIndexes_.find(key) == fullIndexes_.end()) {
+        if (fullIndexes_.find(idxKey) == fullIndexes_.end()) {
 
             // TODO TODO TODO .master.index
-            PathName indexPath(generateIndexPath(key));
+            PathName indexPath(generateIndexPath(idxKey));
 
             // Enforce lustre striping if requested
             if (stripeLustre()) {
                 fdb5LustreapiFileCreate(indexPath.localPath(), stripeIndexLustreSettings());
             }
 
-            fullIndexes_[key] = Index(new TocIndex(key, indexPath, 0, TocIndex::WRITE));
+            fullIndexes_[idxKey] = Index(new TocIndex(idxKey, indexPath, 0, TocIndex::WRITE));
         }
 
-        currentFull_ = fullIndexes_[key];
+        currentFull_ = fullIndexes_[idxKey];
         currentFull_.open();
         currentFull_.flock();
     }
@@ -121,7 +122,7 @@ void TocCatalogueWriter::close() {
     closeIndexes();
 }
 
-void TocCatalogueWriter::index(const Key &key, const eckit::URI &uri, eckit::Offset offset, eckit::Length length) {
+void TocCatalogueWriter::index(const InspectionKey &key, const eckit::URI &uri, eckit::Offset offset, eckit::Length length) {
     dirty_ = true;
 
     if (current_.null()) {
@@ -151,7 +152,7 @@ void TocCatalogueWriter::reconsolidateIndexesAndTocs() {
             writer_(writer) {}
         ~ConsolidateIndexVisitor() override {}
     private:
-        void visitDatum(const Field& field, const Key& key) override {
+        void visitDatum(const Field& field, const InspectionKey& key) override {
             // TODO: Do a sneaky schema.expand() here, prepopulated with the current DB/index/Rule,
             //       to extract the full key, including optional values.
             const TocFieldLocation& location(static_cast<const TocFieldLocation&>(field.location()));
@@ -227,6 +228,11 @@ const Index& TocCatalogueWriter::currentIndex() {
     return current_;
 }
 
+const Key TocCatalogueWriter::currentIndexKey() {
+    currentIndex();
+    return currentIndexKey_;
+}
+
 const TocSerialisationVersion& TocCatalogueWriter::serialisationVersion() const {
     return TocHandler::serialisationVersion();
 }
@@ -294,7 +300,7 @@ bool TocCatalogueWriter::enabled(const ControlIdentifier& controlIdentifier) con
     return TocCatalogue::enabled(controlIdentifier);
 }
 
-void TocCatalogueWriter::archive(const Key& key, std::unique_ptr<FieldLocation> fieldLocation) {
+void TocCatalogueWriter::archive(const InspectionKey& key, std::unique_ptr<FieldLocation> fieldLocation) {
     dirty_ = true;
 
     if (current_.null()) {
@@ -403,7 +409,7 @@ void TocCatalogueWriter::print(std::ostream &out) const {
     out << "TocCatalogueWriter(" << directory() << ")";
 }
 
-static CatalogueBuilder<TocCatalogueWriter> builder("toc.writer");
+static CatalogueWriterBuilder<TocCatalogueWriter> builder("toc");
 
 //----------------------------------------------------------------------------------------------------------------------
 
