@@ -37,13 +37,13 @@ class TocCatalogueWriter : public TocCatalogue, public CatalogueWriter {
 
 public: // methods
 
-    TocCatalogueWriter(const Key &key, const fdb5::Config& config);
+    TocCatalogueWriter(const Key &dbKey, const fdb5::Config& config);
     TocCatalogueWriter(const eckit::URI& uri, const fdb5::Config& config);
 
     virtual ~TocCatalogueWriter() override;
 
     /// Used for adopting & indexing external data to the TOC dir
-    void index(const Key &key, const eckit::URI &uri, eckit::Offset offset, eckit::Length length) override;
+    void index(const InspectionKey &key, const eckit::URI &uri, eckit::Offset offset, eckit::Length length) override;
 
     void reconsolidate() override { reconsolidateIndexesAndTocs(); }
 
@@ -58,11 +58,12 @@ public: // methods
     bool enabled(const ControlIdentifier& controlIdentifier) const override;
 
     const Index& currentIndex() override;
+    const Key currentIndexKey() override;
     const TocSerialisationVersion& serialisationVersion() const;
 
 protected: // methods
 
-    virtual bool selectIndex(const Key &key) override;
+    virtual bool selectIndex(const Key& idxKey) override;
     virtual void deselectIndex() override;
 
     bool open() override;
@@ -70,7 +71,7 @@ protected: // methods
     void clean() override;
     void close() override;
 
-    void archive(const Key& key, std::unique_ptr<FieldLocation> fieldLocation) override;
+    void archive(const InspectionKey& key, std::unique_ptr<FieldLocation> fieldLocation) override;
     void reconsolidateIndexesAndTocs();
 
     virtual void print( std::ostream &out ) const override;
