@@ -34,7 +34,6 @@ eckit::PathName TocCommon::findRealPath(const eckit::PathName& path) {
 
 TocCommon::TocCommon(const eckit::PathName& directory) :
     directory_(findRealPath(directory)),
-    schemaPath_(directory_ / "schema"),
     dbUID_(static_cast<uid_t>(-1)),
     userUID_(::getuid()),
     dirty_(false) {}
@@ -46,7 +45,7 @@ void TocCommon::checkUID() const {
     }
 
     static std::vector<std::string> fdbSuperUsers =
-        eckit::Resource<std::vector<std::string> >("fdbSuperUsers", "", true);
+        eckit::Resource<std::vector<std::string>>("fdbSuperUsers", "", true);
 
     if (dbUID() != userUID_) {
         if (std::find(fdbSuperUsers.begin(), fdbSuperUsers.end(), userName(userUID_)) ==
@@ -79,27 +78,4 @@ std::string TocCommon::userName(uid_t uid) {
     }
 }
 
-FileCopy::FileCopy(const eckit::PathName& srcPath, const eckit::PathName& destPath, const std::string& fileName):
-    src_(srcPath / fileName), dest_(destPath / fileName) {}
-
-FileCopy::FileCopy(eckit::Stream& s) {
-    s >> src_;
-    s >> dest_;
-}
-
-void FileCopy::execute() {
-    eckit::FileHandle src(src_);
-    eckit::FileHandle dest(dest_);
-    src.copyTo(dest);
-}
-
-void FileCopy::encode(eckit::Stream& s) const {
-    s << src_;
-    s << dest_;
-} 
-
-void FileCopy::print(std::ostream &s) const {
-    s << "FileCopy(src=" << src_ << ",dest=" << dest_ << ")";
-}
-
 }
\ No newline at end of file
