@@ -47,7 +47,6 @@ protected: // methods
 protected: // members
 
     const eckit::PathName directory_;
-    const eckit::PathName schemaPath_;
 
     mutable uid_t dbUID_;
     uid_t userUID_;
@@ -55,28 +54,4 @@ protected: // members
     mutable bool dirty_;
 };
 
-// class for writing a chunk of the user buffer - used to perform multiple simultaneous writes
-class FileCopy : public eckit::ThreadPoolTask {
-
-public:
-    FileCopy(const eckit::PathName& srcPath, const eckit::PathName& destPath, const std::string& fileName);    
-    FileCopy(eckit::Stream& s);
-
-    void encode(eckit::Stream&) const;
-
-    void execute() override;
-
-private: // methods
-
-    void print(std::ostream& s) const;
-    friend std::ostream& operator<<(std::ostream& s, const FileCopy& f) {
-        f.print(s);
-        return s;
-    }
-
-private:
-    eckit::PathName src_;
-    eckit::PathName dest_;
-};
-
 }
