@@ -16,8 +16,6 @@
 #include "eckit/config/Resource.h"
 #include "eckit/io/AIOHandle.h"
 #include "eckit/io/EmptyHandle.h"
-#include "eckit/mpi/Comm.h"
-#include "eckit/serialisation/ResizableMemoryStream.h"
 
 #include "fdb5/LibFdb5.h"
 #include "fdb5/rules/Rule.h"
@@ -36,11 +34,11 @@ namespace fdb5 {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-TocStore::TocStore(const Schema& schema, const Key& key, const Config& config) :
-    Store(schema), TocCommon(StoreRootManager(config).directory(key).directory_) {}
+TocStore::TocStore(const Key& key, const Config& config) :
+    Store(), TocCommon(StoreRootManager(config).directory(key).directory_) {}
 
-TocStore::TocStore(const Schema& schema, const eckit::URI& uri, const Config& config) :
-    Store(schema), TocCommon(uri.path().dirName()) {}
+TocStore::TocStore(const eckit::URI& uri, const Config& config) :
+    Store(), TocCommon(uri.path().dirName()) {}
 
 eckit::URI TocStore::uri() const {
     return URI("file", directory_);
@@ -54,7 +52,8 @@ eckit::DataHandle* TocStore::retrieve(Field& field) const {
     return field.dataHandle();
 }
 
-std::unique_ptr<FieldLocation> TocStore::archive(const Key &key, const void *data, eckit::Length length) {
+std::unique_ptr<FieldLocation> TocStore::archive(const Key& key, const void *data, eckit::Length length) {
+    
     dirty_ = true;
 
     eckit::PathName dataPath = getDataPath(key);
@@ -67,7 +66,7 @@ std::unique_ptr<FieldLocation> TocStore::archive(const Key &key, const void *dat
 
     ASSERT(len == length);
 
-    return std::unique_ptr<TocFieldLocation>(new TocFieldLocation(dataPath, position, length, Key()));
+    return std::unique_ptr<FieldLocation>(new TocFieldLocation(dataPath, position, length, Key()));
 }
 
 void TocStore::flush() {
@@ -222,17 +221,17 @@ bool TocStore::canMoveTo(const Key& key, const Config& config, const eckit::URI&
     throw eckit::UserError(ss.str(), Here());
 }
 
-void mpiCopyTask(const eckit::PathName& srcPath, const eckit::PathName& destPath, const std::string& fileName) {
+// void mpiCopyTask(const eckit::PathName& srcPath, const eckit::PathName& destPath, const std::string& fileName) {
 
-    eckit::PathName src_ = srcPath / fileName;
-    eckit::PathName dest_ = destPath / fileName;
+//     eckit::PathName src_ = srcPath / fileName;
+//     eckit::PathName dest_ = destPath / fileName;
 
-    eckit::FileHandle src(src_);
-    eckit::FileHandle dest(dest_);
-    src.copyTo(dest);
-}
+//     eckit::FileHandle src(src_);
+//     eckit::FileHandle dest(dest_);
+//     src.copyTo(dest);
+// }
 
-void TocStore::moveTo(const Key& key, const Config& config, const eckit::URI& dest, bool mpi, int threads) const {
+void TocStore::moveTo(const Key& key, const Config& config, const eckit::URI& dest, eckit::Queue<MoveElement>& queue) const {
     eckit::PathName destPath = dest.path();
     for (const eckit::PathName& root: StoreRootManager(config).canMoveToRoots(key)) {
         if (root.sameAs(destPath)) {      
@@ -253,35 +252,8 @@ void TocStore::moveTo(const Key& key, const Config& config, const eckit::URI& de
             }
             closedir(dirp);
 
-            if (mpi) { // dispatch tasks with MPI
-                eckit::mpi::Comm& comm = eckit::mpi::comm();
-                ASSERT(comm.rank() == 0);
-
-                int ready;
-
-                for (auto it = files.begin(); it != files.end(); it++) {
-                    eckit::mpi::Status status = comm.template receive<int>(&ready, 1, -1, -1);
-
-                    eckit::Buffer sendBuffer;
-                    eckit::ResizableMemoryStream s(sendBuffer);
-                    it->second->encode(s);
-
-                    comm.send(static_cast<const char*>(sendBuffer.data()), s.position(), status.source(), status.tag());
-                }
-
-                eckit::Buffer end;
-
-                // send termination
-                for (int i=1; i<comm.size(); i++) {
-                    eckit::mpi::Status status = comm.template receive<int>(&ready, 1, -1, -1);
-                    comm.send(end.data(), end.size(), status.source(), status.tag());
-                }
-            } else { // spread the load with multiple threads
-                eckit::ThreadPool pool("store"+dest_db.asString(), threads);
-                for (auto it = files.begin(); it != files.end(); it++) {
-                        pool.push(it->second);
-                }
-                pool.wait();
+            for (auto it = files.begin(); it != files.end(); it++) {
+                queue.emplace(*(it->second));
             }
         }
     }
