@@ -73,7 +73,7 @@ void TypeClimateDaily::getValues(const metkit::mars::MarsRequest &request,
                                  const std::string &keyword,
                                  eckit::StringList &values,
                                  const Notifier&,
-                                 const DB*) const {
+                                 const CatalogueReader*) const {
   std::vector<eckit::Date> dates;
 
   request.getValues(keyword, dates, true);
@@ -90,9 +90,8 @@ void TypeClimateDaily::getValues(const metkit::mars::MarsRequest &request,
 bool TypeClimateDaily::match(const std::string&,
                    const std::string& value1,
                    const std::string& value2) const {
-    // std::cout << value1 << " vs. " << value2 << " are " << (month(value1) == month(value2)) << std::endl;
 
-    return month(value1) == month(value2);
+  return month(value1) == month(value2);
 }
 
 void TypeClimateDaily::print(std::ostream &out) const {
