@@ -34,7 +34,7 @@ public: // methods
                            const std::string &keyword,
                            eckit::StringList &values,
                            const Notifier &wind,
-                           const DB *db) const override;
+                           const CatalogueReader* cat) const override;
 
 private: // methods
 
